@@ -23,14 +23,14 @@ class CommandFactory(object):
 		# timestamp of when this message is being generated (now)
 		evaluation.setGeneratedAt(datetime.datetime.now())
 
-		evaluation.addType(RESOURCE.SEAS_COMMAND)
+		evaluation.addType(RESOURCE.COMMAND)
 		
 		return evaluation;
 
 	
 	def fromString(self, data, serialization):
 		try:
-			return Evaluation().parse(Tools().getResourceByType(RESOURCE.SEAS_COMMAND, Tools().fromString(data, serialization)))
+			return Evaluation().parse(Tools().getResourceByType(RESOURCE.COMMAND, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Evaluation by type seas:Command from the given string."
 			traceback.print_exc()
