@@ -1,6 +1,7 @@
 from SeasObjects.rdf.Model import Model
-
+import traceback
 import sys
+import datetime
 
 class Factory(object):
 
@@ -40,3 +41,27 @@ class Factory(object):
 				model.setNsPrefix(field.getName().toLowerCase(), field.get(klazz).toString())
 		except:
 			traceback.print_exc()
+			
+	@classmethod
+	def createTransaction(cls, transactionIdentifierUri, generatedBy):
+		'''
+		return a newly generated Transaction Object 
+		'''
+		from SeasObjects.model.Transaction import Transaction
+		from SeasObjects.model.Activity import Activity
+		from SeasObjects.seasexceptions.InsufficientDataException import InsufficientDataException
+		
+		transaction = Transaction(transactionIdentifierUri)
+		if generatedBy is None:
+			raise InsufficientDataException
+		
+		transaction.setGeneratedBy(Activity(generatedBy))
+		transaction.getGeneratedBy().clearTypes()
+		
+		# timestamp of when this message is being generated (now)
+		transaction.setGeneratedAt(datetime.datetime.now())
+
+		return transaction
+		
+		
+		
