@@ -23,13 +23,12 @@ class NotificationFactory(object):
 
 		# timestamp of when this message is being generated (now)
 		notification.setGeneratedAt(datetime.datetime.now())
-		notification.addType(RESOURCE.SEAS_NOTIFICATION)
-
+		
 		return notification
 
 	def fromString(self, data, serialization):
 		try:
-			return Notification().parse(Tools().getResourceByType(RESOURCE.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
+			return Notification().parse(Tools().getResourceByType(RESOURCE.NOTIFICATION, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Evaluation by type seas:Notification from the given string."
 			traceback.print_exc()
