@@ -55,6 +55,9 @@ class Address(Obj):
 		self.streetAddress = streetAddress
 
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		resource = super(Address, self).serialize(model)
 	
 		# country name
@@ -76,21 +79,8 @@ class Address(Obj):
 		return resource
 
 
-	def parse(self, resource):
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				address = Address(resource.toString())
-			else:
-				address = Address()
-			address.clearTypes()
-			
-			for statement in resource.findProperties():
-				# parse statement
-				address.parse(statement);
-			
-			return address
-		else:
-			statement = resource
+	def parseStatement(self, statement):
+		
 			# get predicate
 			predicate = str(statement.getPredicate())
 	
@@ -131,5 +121,5 @@ class Address(Obj):
 				return
 	
 			# pass on to Object
-			super(Address, self).parse(statement)
+			super(Address, self).parseStatement(statement)
 	
