@@ -22,6 +22,9 @@ class Device(PhysicalEntity):
 		return self.managingSystemUri
 
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		device = super(Device, self).serialize(model)
 
 		# set system uri
@@ -31,22 +34,8 @@ class Device(PhysicalEntity):
 
 		return device
 
-	def parse(self, resource):
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				device = Device(resource.toString())
-			else:
-				device = Device()
-			device.clearTypes()
-	
-			for statement in resource.findProperties():
-				device.parse(statement)
-			
-			return device
-			
-		else:
-			# get predicate
-			statement = resource
+	def parseStatement(self, statement):
+		
 			predicate = str(statement.getPredicate())
 
 			# ismanagedby
@@ -59,5 +48,5 @@ class Device(PhysicalEntity):
 				return 
 			
 			# pass on to Object
-			super(Device, self).parse(statement)
+			super(Device, self).parseStatement(statement)
 
