@@ -30,6 +30,9 @@ class Error(Obj):
 		return self.message != None
 	
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		error = super(Error, self).serialize(model)
 		
 		if self.hasErrorMessage():
@@ -40,28 +43,22 @@ class Error(Obj):
 		
 		return error
 	
-	def parse(self, resource):
-		if not resource.isAnon():
-			e = Error(resource.toString())
-		else:
-			e = Error()
-		e.clearTypes()
-
-		for statement in resource.findProperties():
+	def parseStatement(self, statement):
+		
 			# get predicate
 			predicate = str(statement.getPredicate())
 
 			# managedby
 			if predicate == PROPERTY.ERRORMESSAGE:
-				e.message = statement.getResource().toString()
-				continue
+				self.message = statement.getResource().toString()
+				return
 
 			# interfaceaddress
 			if predicate == PROPERTY.ERRORCODE:
-				e.code = int(statement.getResource().toString())
-				continue
+				self.code = int(statement.getResource().toString())
+				return
 
 			# pass on to Object
-			super(Error, self).parse(statement)
+			super(Error, self).parseStatement(statement)
+		
 		
-		return e
