@@ -17,6 +17,9 @@ class Input(Evaluation):
 		self.setType(RESOURCE.INPUT)
 	
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		input = super(Input, self).serialize(model)
 		
 		# outputs
@@ -25,35 +28,21 @@ class Input(Evaluation):
 			
 		return input
 
-	def parse(self, resource):
+	def parseStatement(self, statement):
 		from SeasObjects.model.ValueObject import ValueObject
+				
+		predicate = str(statement.getPredicate())
 		
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				input = Input(resource.toString())
-			else:
-				input = Input()
-			input.clearTypes()
-			
-			for i in resource.findProperties():
-				# pass on to Evaluation
-				input.parse(i)
-			
-			return input
-		else:
-			statement = resource
-			predicate = str(statement.getPredicate())
-			
-			# output vals
-			if  predicate == PROPERTY.OUTPUTVALUES:
-				try:
-					self.addOutputValue(ValueObject().parse(statement.getResource()));
-				except:
-					print "Unable to interpret seas:outputValues value as resource."
-					traceback.print_exc()
-				return
+		# output vals
+		if  predicate == PROPERTY.OUTPUTVALUES:
+			try:
+				self.addOutputValue(ValueObject().parse(statement.getResource()));
+			except:
+				print "Unable to interpret seas:outputValues value as resource."
+				traceback.print_exc()
+			return
 
-			super(Input, self).parse(resource)
+		super(Input, self).parseStatement(statement)
 
 	def getInputType(self):
 		return self.inputType
