@@ -27,6 +27,9 @@ class Service(AbstractEntity):
 		return self.managedBy
 	
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		service = super(Service, self).serialize(model)
 		
 		# set system uri
@@ -36,35 +39,21 @@ class Service(AbstractEntity):
 		return service
 	
 	
-	def parse(self, resource):
+	def parseStatement(self, statement):
 		from SeasObjects.model.Obj import Obj
 		from SeasObjects.model.InterfaceAddress import InterfaceAddress
-		
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				service = Service(resource.toString())
-			else:
-				service = Service()
-			service.clearTypes()
-	
-			for statement in resource.findProperties():
-				service.parse(statement)
-			
-			return service
-		
-		else:
-			statement = resource
-			# get predicate
-			predicate = str(statement.getPredicate())
+				
+		# get predicate
+		predicate = str(statement.getPredicate())
 
-			# managedby
-			if predicate == PROPERTY.ISMANAGEDBY:
-				try:
-					self.managedBy = Obj().parse(statement.getResource())
-				except:
-					print "Unable to interpret seas:isManagedBy value as resource."
-					traceback.print_exc() 
+		# managedby
+		if predicate == PROPERTY.ISMANAGEDBY:
+			try:
+				self.managedBy = Obj().parse(statement.getResource())
+			except:
+				print "Unable to interpret seas:isManagedBy value as resource."
+				traceback.print_exc() 
 
-			# pass on to Object
-			super(Service, self).parse(statement)
+		# pass on to Object
+		super(Service, self).parseStatement(statement)
 
