@@ -22,6 +22,9 @@ class ServiceProvider(AbstractEntity):
 		return self.services
 
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		entity = super(ServiceProvider, self).serialize(model);
 		
 		# set services
@@ -31,36 +34,21 @@ class ServiceProvider(AbstractEntity):
 		
 		return entity
 	
-	def parse(self, resource):
+	def parseStatement(self, statement):
 		from SeasObjects.model.Service import Service
-		
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				serviceProvider = ServiceProvider(resource.toString())
-			else:
-				serviceProvider = ServiceProvider()
-			serviceProvider.clearTypes()
-	
-			for statement in resource.findProperties():
-				# parse statement
-				serviceProvider.parse(statement);
-	
-			return serviceProvider
-		
-		else:
-			statement = resource
-			# get predicate
-			predicate = str(statement.getPredicate())
-	
-			# offersservice
-			if predicate == PROPERTY.OFFERSSERVICE:
-				try:
-					self.addService(Service().parse(statement.getResource()))
-				except:
-					print "Unable to interpret seas:offersService value as resource."
-					traceback.print_exc() 
 				
-				return
-	
-			# pass on to Object
-			super(ServiceProvider, self).parse(statement)
+		# get predicate
+		predicate = str(statement.getPredicate())
+
+		# offersservice
+		if predicate == PROPERTY.OFFERSSERVICE:
+			try:
+				self.addService(Service().parse(statement.getResource()))
+			except:
+				print "Unable to interpret seas:offersService value as resource."
+				traceback.print_exc() 
+			
+			return
+
+		# pass on to Object
+		super(ServiceProvider, self).parseStatement(statement)
