@@ -86,6 +86,9 @@ class Velocity(Obj):
 		return self.groundSpeed
 		
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		speed = super(Velocity, self).serialize(model)
 		
 		if self.hasAngularVelocityX():
@@ -107,21 +110,8 @@ class Velocity(Obj):
 
 		return speed
 	
-	def parse(self, resource):
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				speed = Velocity(resource.toString())
-			else:
-				speed = Velocity()
-			speed.clearTypes()
-			
-			for statement in resource.findProperties():
-				# parse statement
-				speed.parse(statement);
-			
-			return speed
-		else:
-			statement = resource
+	def parseStatement(self, statement):
+		
 			# get predicate
 			predicate = str(statement.getPredicate())
 	
@@ -188,5 +178,5 @@ class Velocity(Obj):
 				return
 				
 			# pass on to Object
-			super(Velocity, self).parse(statement)
+			super(Velocity, self).parseStatement(statement)
 	
