@@ -25,6 +25,9 @@ class Zone(Obj):
 		self.zoneNumber = zoneNumber
 
 	def serialize(self, model):
+		if self.serializeAsReference:
+			return self.serializeToReference(model)
+		
 		resource = super(Zone, self).serialize(model)
 	
 		# set zone
@@ -34,21 +37,8 @@ class Zone(Obj):
 		return resource
 
 
-	def parse(self, resource):
-		if isinstance(resource, Resource):
-			if not resource.isAnon():
-				z = Zone(resource.toString())
-			else:
-				z = Zone()
-			z.clearTypes()
-			
-			for statement in resource.findProperties():
-				# parse statement
-				z.parse(statement);
-			
-			return z
-		else:
-			statement = resource
+	def parseStatement(self, statement):
+		
 			# get predicate
 			predicate = str(statement.getPredicate())
 	
@@ -62,5 +52,5 @@ class Zone(Obj):
 				return
 		
 			# pass on to Object
-			super(Zone, self).parse(statement)
+			super(Zone, self).parseStatement(statement)
 	
