@@ -221,9 +221,9 @@ class Resource(object):
         ostmt = None
         # Statement for first list element (the actual object)
         if isinstance(var, RdfLiteral):
-            o = makeLiteral(var)
+            o = self.makeLiteral(var)
         elif isinstance(var, Resource):
-            o = bNode
+            o = BNode()
             ostmt = var.listProperties(subject = o)
         elif isinstance(var, Variant):
             o = var.asTerm()
@@ -294,7 +294,7 @@ class Resource(object):
 
     # transforms the resource into a Python list. Requires that the node
     # is in the form of an RDF list (has first, rest properties
-    def toList(self, klass):
+    def toList(self, klass):       
         l = []
         sl = self.model.listStatements(subject = self.node, predicate = URIRef(RDF.first), object = None)
         for s in sl:
